package productlogic

import (
	"code.30cm.net/digimon/app-cloudep-product-service/pkg/domain/entity"
	domainProduct "code.30cm.net/digimon/app-cloudep-product-service/pkg/domain/product"
	"code.30cm.net/digimon/library-go/errs"
	"context"
	"fmt"

	"code.30cm.net/digimon/app-cloudep-product-service/gen_result/pb/product"
	"code.30cm.net/digimon/app-cloudep-product-service/internal/svc"

	"github.com/zeromicro/go-zero/core/logx"
)

type CreateTagsLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewCreateTagsLogic(ctx context.Context, svcCtx *svc.ServiceContext) *CreateTagsLogic {
	return &CreateTagsLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *CreateTagsLogic) CreateTags(in *product.CreateTagsReq) (*product.OKResp, error) {
	t, err := safeItemType(in.GetTypes())
	if err != nil {
		return nil, errs.InvalidFormat("failed to validate item type")
	}

	insert := &entity.Tags{
		Types:    t,
		Name:     in.GetName(),
		ShowType: domainProduct.ShowType(in.GetShowType()),
	}

	if in.Cover != nil {
		insert.Cover = in.Cover
	}

	err = l.svcCtx.TagsUseCase.Create(l.ctx, insert)
	if err != nil {
		return nil, err
	}

	return &product.OKResp{}, nil
}

func safeItemType(t int32) (domainProduct.ItemType, error) {
	if t < -128 || t > 127 {
		return 0, fmt.Errorf("invalid ItemType value: %d", t)
	}
	return domainProduct.ItemType(t), nil
}
