package productlogic

import (
	"context"

	"code.30cm.net/digimon/app-cloudep-product-service/gen_result/pb/product"
	"code.30cm.net/digimon/app-cloudep-product-service/internal/svc"

	"github.com/zeromicro/go-zero/core/logx"
)

type FindKYCByIDLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewFindKYCByIDLogic(ctx context.Context, svcCtx *svc.ServiceContext) *FindKYCByIDLogic {
	return &FindKYCByIDLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

// FindKYCByID 根據 KYC ID 查詢
func (l *FindKYCByIDLogic) FindKYCByID(in *product.FindKYCByIDReq) (*product.KYC, error) {
	kycInfo, err := l.svcCtx.KYCUseCase.FindByID(l.ctx, in.GetId())
	if err != nil {
		return nil, err
	}

	return &product.KYC{
		Id:                 kycInfo.ID.Hex(),
		Uid:                kycInfo.UID,
		CountryRegion:      kycInfo.CountryRegion,
		Name:               kycInfo.Name,
		Identification:     kycInfo.Identification,
		IdentificationType: kycInfo.IdentificationType,
		Address:            kycInfo.Address,
		PostalCode:         kycInfo.PostalCode,
		// 上傳文件網址（可為 object storage 的 URL）
		IdFrontImage:     kycInfo.IDFrontImage,
		IdBackImage:      kycInfo.IDBackImage,
		BankStatementImg: kycInfo.BankStatementImg,
		BankCode:         kycInfo.BankCode,
		BankName:         kycInfo.BankName,
		BranchCode:       kycInfo.BranchCode,
		BranchName:       kycInfo.BranchName,
		BankAccount:      kycInfo.BankAccount,
		Status:           kycInfo.Status.ToString(),
		RejectReason:     kycInfo.RejectReason,
		UpdatedAt:        kycInfo.UpdatedAt,
		CreatedAt:        kycInfo.CreatedAt,
	}, nil
}
